@@ -82,6 +82,10 @@ void MainWindow::headphoneEvent(QString what,QString how)
 
 }
 
+void MainWindow::dbus(QString what,QString how){
+    qDebug(what.toAscii());
+    qDebug(how.toAscii());
+}
 
 #endif
 
@@ -180,12 +184,19 @@ for (int i = 0; i < 10; ++i)
     sliders.append(s);
 }
 QCheckBox *enabled = new QCheckBox("Enable equalizer");
-enabled->setChecked(false);
+if (get_setting("eq_state")=="1")enabled->setChecked(true); else enabled->setChecked(false);
+toggleEqualizer(enabled->isChecked());
 connect(enabled, SIGNAL(toggled(bool)), this, SLOT(toggleEqualizer(bool)));
+
+
 vb->addWidget(enabled);
 vb->addLayout(lt);
-QPushButton *reset = new QPushButton("Reset sliders");
-connect (reset, SIGNAL(clicked()), this, SLOT(resetAll()));
+QPushButton *reset = new QPushButton("Functions");
+
+eq_menu=new QMenu;
+load_eqs();
+
+connect (reset, SIGNAL(clicked()), this,SLOT(eq_fn_click()));
 vb->addWidget(reset);
 setLayout(vb);
 
@@ -286,6 +297,7 @@ scroller2->setEnabled(true);
 
     QDBusConnection::systemBus().connect(QString(), "/org/freedesktop/Hal/devices/platform_headphone", "org.freedesktop.Hal.Device", "Condition", this, SLOT(headphoneEvent(QString,QString)));
 
+
 #endif
 
  QList<QWidget *> widgets = this->ui.centralwidget->findChildren<QWidget *>();
@@ -300,6 +312,101 @@ if (row!=-1){
                     "org.freedesktop.Hal.Device",
                     QDBusConnection::systemBus()).call ("GetProperty", "button.state.value").arguments().at(0).toBool())play_pause();
 }
+
+eq_name=get_setting("last_eq");
+if (eq_name.isEmpty())eq_name="Default";
+load_eq(eq_name);
+
+}
+
+void MainWindow::load_eqs(){
+    eq_menu->clear();
+    QMenu *fn=new QMenu("Equalizer",eq_menu);
+     fn->addAction("Save to new",this,SLOT(save_eq_d()));
+     fn->addAction("Save current",this,SLOT(save_eq()));
+     fn->addAction("Remove current",this,SLOT(rem_eq()));
+
+
+    QString sql="SELECT `name` FROM `equalizer` WHERE 1";
+    QSqlQuery query(sql);
+         while (query.next()) {
+             QString nm=query.value(0).toString();
+             eq_menu->addAction(nm,this,SLOT(eq_load_mn()));
+         }
+
+
+
+}
+
+void MainWindow::eq_fn_click(){
+    // just a wraper
+    eq_menu->exec(QCursor::pos());
+}
+
+void MainWindow::eq_load_mn(){
+QAction *action = qobject_cast<QAction *>(sender());
+load_eq(action->text());
+}
+
+void MainWindow::load_eq(QString name){
+    QString sql="SELECT * FROM `equalizer` WHERE `name`='"+name+"'";
+    QSqlQuery query(sql);
+         while (query.next()) {
+             for (int i=0;i<10;i++){
+             QString nm=query.value(i+1).toString();
+            sliders[i]->setValue(nm.toLong());
+                }
+         }
+
+         eq_name=name;
+     set_setting("last_eq",name);
+}
+void MainWindow::save_eq_d(){
+    QDialog *d=new QDialog();
+    QVBoxLayout *h=new QVBoxLayout(d);
+    QLabel *y=new QLabel("<center>New equalizer name</center>",d);
+    QLineEdit *u=new QLineEdit(d);
+    QPushButton *ok=new QPushButton("Create equalizer",d);
+    h->addWidget(y);
+    h->addWidget(u);
+    h->addWidget(ok);
+    connect (ok,SIGNAL(clicked()),d,SLOT(accept()));
+    d->exec();
+    QString nn=u->text().replace("'","''").trimmed();
+
+if (!nn.isEmpty())save_eq(nn);
+}
+
+void MainWindow::save_eq(){
+    save_eq(eq_name);
+}
+void MainWindow::rem_eq(){
+db.exec("DELETE FROM `equalizer` WHERE `name`='"+eq_name+"'");
+}
+void MainWindow::save_eq(QString name){
+db.exec("DELETE FROM `equalizer` WHERE `name`='"+name+"'");
+QString sql=QString("INSERT INTO `equalizer` (name,eq1,eq2,eq3,eq4,eq5,eq6,eq7,eq8,eq9,eq10) "
+        "VALUES ('%1','%2','%3','%4','%5','%6','%7','%8','%9','%10','%11')")
+            .arg(name)
+            .arg(sliders[0]->value())
+            .arg(sliders[1]->value())
+            .arg(sliders[2]->value())
+            .arg(sliders[3]->value())
+            .arg(sliders[4]->value())
+            .arg(sliders[5]->value())
+            .arg(sliders[6]->value())
+            .arg(sliders[7]->value())
+            .arg(sliders[8]->value())
+            .arg(sliders[9]->value());
+
+
+    if(!db.exec(sql).isValid())
+   qDebug(db.lastError().text().toAscii());
+db.commit();
+
+
+
+load_eqs();
 }
 
 void MainWindow::reload(){
@@ -476,10 +583,17 @@ s->setValue(0);
 
 void MainWindow::toggleEqualizer(bool val)
 {
-    if (val)
+    if (val){
        audioPath.insertEffect(eqEffect);
-    else
+       set_setting ("eq_state","1");
+   }
+    else{
        audioPath.removeEffect (eqEffect);
+       set_setting ("eq_state","0");
+   }
+
+
+
 }
 
 
@@ -604,7 +718,9 @@ dg->exec();
 
 void MainWindow::fmtx_change(int state){
     try{
-
+        set_setting("FMTX-name",ui.lineEdit->text());
+        set_setting("FMTX-text",ui.lineEdit_2->text());
+        set_setting("FMTX-freq",QString("%1").arg(ui.doubleSpinBox->value()));
 
     if (state==Qt::Checked){
         // enable
@@ -650,15 +766,8 @@ void MainWindow::fmtx_change(int state){
 
 MainWindow::~MainWindow()
 {
-set_setting("last_played",list.value(ui.listWidget->currentRow()).at(0) );
-
-set_setting("FMTX-name",ui.lineEdit->text());
-set_setting("FMTX-text",ui.lineEdit_2->text());
-set_setting("FMTX-freq",QString("%1").arg(ui.doubleSpinBox->value()));
 
 
-db.commit();
-db.close();
 }
 
 void MainWindow::metaStateChanged(Phonon::State newState, Phonon::State /* oldState */)
@@ -816,16 +925,25 @@ void MainWindow::currentItemChanged ( QListWidgetItem * current ){
 void MainWindow::changePlay( Phonon::State newstate, Phonon::State oldstate ) {
     try{
         if (inet_source==0){
+            set_setting("last_played",list.value(ui.listWidget->currentRow()).at(0) );
+
+
+            emit this->track_change(moo->currentSource().fileName());
+
     ui.label->setText(list.value(ui.listWidget->currentRow()).at(2)+" - "+list.value(ui.listWidget->currentRow()).at(1));
     this->setWindowTitle(list.value(ui.listWidget->currentRow()).at(2)+" - "+list.value(ui.listWidget->currentRow()).at(1));
     if (newstate==Phonon::PlayingState&&oldstate!=Phonon::PausedState){
 
+        track_title=list.value(ui.listWidget->currentRow()).at(1);
+        track_artist=list.value(ui.listWidget->currentRow()).at(2);
+        track_album=list.value(ui.listWidget->currentRow()).at(3);
+
 scrobler->now(list.value(ui.listWidget->currentRow()),moo->totalTime());
 
 #ifdef Q_WS_MAEMO_5
     if (!this->isActiveWindow()){
    QMaemo5InformationBox *box=new QMaemo5InformationBox();
-   QLabel *lbl=new QLabel("Now playing :"+list.value(ui.listWidget->currentRow()).at(2)+" - "+list.value(ui.listWidget->currentRow()).at(1),box);
+   QLabel *lbl=new QLabel("<center>Now playing :"+list.value(ui.listWidget->currentRow()).at(2)+" - "+list.value(ui.listWidget->currentRow()).at(1)+"</center>",box);
   box->setWidget (lbl);
 box->setTimeout(3000);
 connect(box,SIGNAL(clicked()),this,SLOT(setFocus()));
