@@ -22,6 +22,7 @@
 class MainWindow : public QMainWindow, private Ui::MainWindow
 {
     Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.tplayer")
 
 public:
     MainWindow(QWidget *parent = 0);
@@ -59,10 +60,21 @@ public:
     int on_start;
     int inet_source;
     QString current_path;
-
+    QString track_title,track_artist,track_album;
+    QString eq_name;
+    QMenu *eq_menu;
 signals:
-            void track_change(QString );
+    Q_SCRIPTABLE void track_change(QString );
 public slots:
+    void rem_eq();
+    void eq_fn_click();
+    void save_eq_d();
+    void eq_load_mn();
+    void load_eqs();
+    void load_eq(QString);
+    void save_eq();
+    void save_eq(QString);
+
 
     void load_inet();
     void inet(QListWidgetItem*);
@@ -88,9 +100,9 @@ public slots:
     void pl_fn_click();
     void pl_fn_add_dir();
     void currentItemChanged ( QListWidgetItem * );
-    void play_pause();
-    void next();
-    void prev();
+    Q_SCRIPTABLE void play_pause();
+    Q_SCRIPTABLE void next();
+    Q_SCRIPTABLE void prev();
     void changePlay( Phonon::State, Phonon::State ) ;
     void clear();
     void replyFinished(QNetworkReply*);
@@ -105,6 +117,7 @@ public slots:
     #ifdef Q_WS_MAEMO_5
     void grabZoomKeys(bool grab);
     void headphoneEvent (QString,QString);
+    void dbus (QString,QString);
     #endif
     void dart();
     void dart2();
